##  Troubleshooting
  * Check attribute mappings using a SAML tracer.
  * If the problems persist, submit a ticket to support.


### Reverting the SSO Migration
If something goes wrong during the self-service SSO configuration migration, contact support to revert the changes. Follow these steps:
  1. Go to [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2Fgetsupport "https://me.sap.com/getsupport").
  2. Enter the ticket title: "Revert self-service SSO configuration migration for workspace [your workspace name]".
  3. Provide your workspace details and reason for reverting:
     * Workspace name
     * Subdomain, for example, "customername.leanix.net" or "http://eu.leanix.net"
     * Migration completion date (if known)
     * Reason for reverting
  4. Provide the migration steps already completed, for example:
     * Created an app in the identity provider (IdP) system
     * Created an IdP in SAP LeanIX
     * Enabled the IdP in SAP LeanIX
  5. Choose SAP LeanIX as the system, then populate the other required fields and submit the ticket.


The SAP LeanIX support team assists with rolling back the changes to your previous SSO configuration.
